clear
set mem 500m
set more off

/*	****************************************************************	*/
/*	File Name:	thyne_lexington_reps.do						*/
/*	Version:	Stata 9 or above.							*/
/*	Date: 	April 16, 2009							*/
/*	Author: 	Clayton L. Thyne							*/
/*	Purpose:	This file replicates the regression results for: 	*/
/*	Thyne, Clayton L. (2009). How International Relations Affect 	*/
/*	Civil Conflict: Cheap Signals, Costly Consequences. 			*/
/*	Lexington, MA: Lexington Books.						*/
/*	****************************************************************	*/

/*	Chapter 3, Table 3.3	*/
use ch3_monadic.dta, clear
logit onset mid gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 , nolog
logit onset trade gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog
logit onset alliances gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog
logit onset sanctions gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog
logit onset mid trade alliances sanctions gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog
logit onset mid_neigh gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if borders~=., nolog
logit onset trade_neigh gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if borders~=. ,nolog
logit onset alliances_neigh gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if borders~=. ,nolog
logit onset mid_neigh trade_neigh alliances_neigh gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if borders~=.,nolog

/*	Chapter 3, Table 3.4	*/
use ch3_monadic.dta, clear
logit onset cheap_signals gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog
logit onset cheap_signals gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if cheap_signals<=4.5 & cheap_signals>=-7 ,nolog
logit onset cheap_signals mid sanctions trade alliances gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if cheap_signals<=4.5 & cheap_signals>=-7 ,nolog

/*	Chapter 3, Table 3.5	*/
use ch3_monadic.dta, clear
logit onset across_volatility gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if cheap_signals<=4.5 & cheap_signals>=-7 ,nolog
logit onset within_volatility gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if cheap_signals<=4.5 & cheap_signals>=-7 ,nolog
logit onset temporal_volatility gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if cheap_signals<=4.5 & cheap_signals>=-7 ,nolog
logit onset neg_shock gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if cheap_signals>=-7 & cheap_signals<=4.5,nolog
logit onset pos_shock gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if cheap_signals>=-7 & cheap_signals<=4.5,nolog
logit onset across_volatility within_volatility neg_shock pos_shock temporal_volatility mid trade alliances sanctions ///
	gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3 if cheap_signals<=4.5 & cheap_signals>=-7 ,nolog

/*	Chapter 3, Table 3.6	*/
use ch3_dyadic.dta, clear
logit onset cheap_signals gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact1 dem_signaler gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact2 nondem_signaler gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact3 same_regime gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact4 diff_regime gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact5 same_culture gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact6 diff_culture gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact7 strong_signaler gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact8 weak_signaler gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact9 consistent_signaler gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)
logit onset cheap_signals interact10 incons_signaler gdppc pop oil mountains instab anoc dem peace_yrs _spline1 _spline2 _spline3, nolog cluster(dyad)

/*	Chapter 5, Table 5.3	*/
use ch5_6.dta, clear
stset duration, id(id) failure(failure)
streg old_interv battle_deaths gdppc pop fight_gov, d(w) nolog time robust 
streg signal_deviation battle_deaths gdppc pop fight_gov, d(w) nolog time robust
streg any_exp battle_deaths gdppc pop fight_gov, d(w) nolog time robust
streg R_exp G_exp battle_deaths gdppc pop fight_gov, d(w) nolog time robust 
streg any_weak battle_deaths gdppc pop fight_gov, d(w) nolog time robust
streg R_weak G_weak battle_deaths gdppc pop fight_gov, d(w) nolog time robust

/*	Chapter 6, Table 6.2	*/
use ch5_6.dta, clear
stset duration, id(id) failure(vgov==1)
streg R_weak battle_deaths gdppc pop fight_gov if vgov~=., d(w) nolog time robust 
streg R_exp R_weak battle_deaths gdppc pop fight_gov if vgov~=., d(w) nolog time robust 
stset duration, id(id) failure(vreb==1)
streg G_weak battle_deaths gdppc pop fight_gov if vreb~=., d(w) nolog time robust 
streg G_exp G_weak battle_deaths gdppc pop fight_gov if vreb~=., d(w) nolog time robust